package com.inspect.metadata.station.mapper;

import com.inspect.metadata.station.domain.BasedataStation;

import java.util.List;
import java.util.Map;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

@Mapper
public interface BasedataStationMapper {
    BasedataStation selectBasedataStationByStationId(String stationId);

    List<BasedataStation> selectBasedataStationList(BasedataStation station);

    int insertBasedataStation(BasedataStation station);

    int updateBasedataStation(BasedataStation station);

    int deleteBasedataStationByStationId(String stationId);

    int deleteBasedataStationByStationIds(String[] stationIds);

    BasedataStation getStationTypeByPatrolPointId(String pointId);

    int checkStationNameIsExit(@Param("stationName") String stationName, @Param("stationNo") String stationNo, @Param("stationId") String stationId);

    List<Map> getStationNameList();
}
